# npqtools

Данная Python-библиотека создана для решения популярных NP-сложных задач, таких как:

1) Задача о плотном замощении
2) Задача коммивояжера
3) Задача о распределении работ по машинам
4) Задача о поиске клики
5) Задача о поиске максимальной клики во взвешенном графе
6) Задача о многомерном рюкзаке


И другие

Задачи сводятся к решению QUBO (Quadratic unconstrained binary optimization) при помощи сервиса Dwave

Подробнее Documentation.pdf